@@ -2,13 +2,13 @@
 # @file    __version__.py
 # @brief   GillesPy2 version info
 # @license Please see the file named LICENSE in the project directory
-# @website https://github.com/GillesPy2/GillesPy2
+# @website https://github.com/StochSS/GillesPy2
 # =============================================================================
 
-__version__      = '1.3.1'
+__version__      = '1.5.6'
 __title__        = 'GillesPy2'
 __description__  = 'Python interface for Gillespie-style biochemical simulations'
-__url__          = 'https://github.com/GillesPy2/GillesPy2'
+__url__          = 'https://github.com/StochSS/GillesPy2'
 __download_url__ = 'https://pypi.org/project/gillespy2/#files'
 __author__       = 'See AUTHORS'
 __email__        = 'bdrawert@unca.edu'
