@@ -1,11 +1,9 @@
 import unittest
 import tempfile
 import os
-from gillespy2.core import Model, import_SBML
-from gillespy2.sbml import SBMLimport
-from gillespy2.core.gillespyError import *
-from gillespy2.solvers.numpy.basic_ode_solver import BasicODESolver
-import numpy as np
+from gillespy2.core.model import import_SBML
+from gillespy2 import ODESolver
+
 
 class TestSBML(unittest.TestCase):
 
@@ -21,14 +19,15 @@ class TestSBML(unittest.TestCase):
         except ImportError:
             from urllib.request import urlopen
 
-        sbml_file = 'http://www.ebi.ac.uk/biomodels-main/download?mid=BIOMD0000000028'
+        sbml_file = 'https://www.ebi.ac.uk/biomodels/model/download/BIOMD0000000028.2?filename=BIOMD0000000028_url.xml'
         response = urlopen(sbml_file)
-        tmp = tempfile.NamedTemporaryFile(delete = False)
+        tmp = tempfile.NamedTemporaryFile(delete=False)
         tmp.write(response.read())
         tmp.close()
         sbml_model, errors = import_SBML(tmp.name)
         os.remove(tmp.name)
-        sbml_results = sbml_model.run(solver=BasicODESolver)
+        sbml_results = sbml_model.run(solver=ODESolver)
+
 
 if __name__ == '__main__':
     unittest.main()
